"""
Author: {{ data["author"] }}
Author Link: {{ data["author_link"] }}
License: {{ data["license"] }}
Date:  {{ data["date"] }}
Answer Url: {{ data["post_url"] }}
"""

__title__ = '{{ data["title"] }}'
__version__ = '{{ data["version"] }}'
__author__ = '{{ data["author"] }}'
__license__ = '{{ data["license"] }}'
__copyright__ = '{{ data["copyright"] }}'
