[metadata]
author = {{ item["author"] }}
author_email = {{ item["author_email"] }}
classifiers =
{{ item["classifiers"] }}
description = {{ item["description"] }}
long_description = file:README.md
long_description_content_type = text/markdown
license = {{ item["license"] }}
license_file = LICENSE
name = {{ item["package_name"] }}
project_urls =
Source Code = {{ item["source_url"] }}
Change Log = {{ item["revisions_url"] }}
url = {{ item["source_url"] }}
version = {{ item["version"] }}

[options]
install_requires =
{% for dependency in item["dependencies"] %}{{ dependency }}
{% endfor %}
package_dir =
={{ item["src_folder"] }}
packages = find:
python_requires = {{ item["python_version"] }}

[options.packages.find]
where={{ item["src_folder"] }}
