# Authors
#
# Note:
# - Authors listed alphabetically
# - Some users leave StackOverflow or are removed, but their content stays
# - Some users post content they copied verbatim from other sites on the web
# - Some answers are "forks" of other answers, I don't attempt to detect this.
# - Email addresses are from unobfuscated addresses in the profile
# - License can vary by contribution

{% for section, authors in item["authors"].items() %}
# {{ section }}
--------------
{% for author in authors %}{{ author.display_name }} {% for url in author.urls %}<{{ url }}>{%- if not loop.last -%}, {% endif %}{% endfor %} {% for email in author.emails %}<{{ url }}>{%- if not loop.last -%}, {% endif %}{% endfor %}
{% endfor %}{%- endfor -%}
