<!DOCTYPE html>


<html class="html__responsive html__unpinned-leftnav">

<head>

    <title>Code of Conduct - Stack Overflow</title>
    <link rel="shortcut icon" href="https://cdn.sstatic.net/Sites/stackoverflow/Img/favicon.ico?v=ec617d715196">
    <link rel="apple-touch-icon"
          href="https://cdn.sstatic.net/Sites/stackoverflow/Img/apple-touch-icon.png?v=c78bd457575a">
    <link rel="image_src" href="https://cdn.sstatic.net/Sites/stackoverflow/Img/apple-touch-icon.png?v=c78bd457575a">
    <link rel="search" type="application/opensearchdescription+xml" title="Stack Overflow" href="/opensearch.xml">
    <meta name="viewport" content="width=device-width, height=device-height, initial-scale=1.0, minimum-scale=1.0">
    <meta property="og:type" content="website"/>
    <meta property="og:url" content="https://stackoverflow.com/conduct"/>
    <meta property="og:site_name" content="Stack Overflow"/>
    <meta property="og:image" itemprop="image primaryImageOfPage"
          content="https://cdn.sstatic.net/Sites/stackoverflow/Img/apple-touch-icon@2.png?v=73d79a89bded"/>
    <meta name="twitter:card" content="summary"/>
    <meta name="twitter:domain" content="stackoverflow.com"/>
    <meta name="twitter:title" property="og:title" itemprop="name" content="Code of Conduct"/>
    <meta name="twitter:description" property="og:description" itemprop="description"
          content="Stack Overflow | The World&#x2019;s Largest Online Community for Developers"/>

    <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.12.4/jquery.min.js"></script>
    <script src="https://cdn.sstatic.net/Js/stub.en.js?v=95d1ce093683"></script>

    <link rel="stylesheet" type="text/css" href="https://cdn.sstatic.net/Shared/stacks.css?v=50b8afc7d7a9">
    <link rel="stylesheet" type="text/css"
          href="https://cdn.sstatic.net/Sites/stackoverflow/primary.css?v=ed592cf7c761">
    <link rel="stylesheet" type="text/css"
          href="https://cdn.sstatic.net/Sites/stackoverflow/secondary.css?v=d614bb0f1de9">


    <link rel="stylesheet" type="text/css" href="https://cdn.sstatic.net/Shared/Product/product.css?v=6d79cc50f79b">


    <script>
        StackExchange.ready(function () {
            var d = 100;
            $.ajax({
                url: "https://cdn.sstatic.net/WinterBash/js/wb-kovah.min.js?v=7",
                cache: true,
                dataType: "script"
            }).done(function tryInit() {
                if (window.WinterBash) {
                    WinterBash.core.init('winterbash2020.stackexchange.com', 'https://cdn.sstatic.net/WinterBash/', '7', false);
                } else {
                    if (d <= 800)
                        setTimeout(tryInit, d);
                    d *= 2;
                }
            });
        });
        document.write('<style id="wb-snowflake-placeholder" type="text/css">.site-switcher-item { margin-left: 38px; } @media screen and (max-width: 640px) { html.html__responsive .site-switcher-item { margin-left: 34px; } }</style>');
    </script>

    <script>
        StackExchange.ready(function () {
            StackExchange.realtime.init('wss://qa.sockets.stackexchange.com');
            StackExchange.realtime.subscribeToReputationNotifications('1');
            StackExchange.realtime.subscribeToTopBarNotifications('1');
        });
    </script>
    <script>
        StackExchange.init({
            "locale": "en",
            "serverTime": 1609429033,
            "routeName": "Help/Conduct",
            "stackAuthUrl": "https://stackauth.com",
            "networkMetaHostname": "meta.stackexchange.com",
            "site": {
                "name": "Stack Overflow",
                "description": "Q&A for professional and enthusiast programmers",
                "isNoticesTabEnabled": true,
                "enableNewTagCreationWarning": true,
                "insertSpaceAfterNameTabCompletion": false,
                "id": 1,
                "childUrl": "https://meta.stackoverflow.com",
                "styleCodeWithHighlightjs": true,
                "negativeVoteScoreFloor": null,
                "enableSocialMediaInSharePopup": true,
                "protocol": "https"
            },
            "user": {
                "fkey": "e65640ce4fbe13142433c9ec7e081225b004e8a26f3543fa5b88e765fa6767bd",
                "tid": "bff4fff3-5441-b482-1891-298ca167f8b5",
                "rep": 29858,
                "isRegistered": true,
                "userType": 3,
                "userId": 33264,
                "accountId": 15651,
                "gravatar": "<div class=\"gravatar-wrapper-32\"><img src=\"https://www.gravatar.com/avatar/4ffb7620821b43c340d40187ca5820ff?s=32&amp;d=identicon&amp;r=PG\" alt=\"\" width=\"32\" height=\"32\" class=\"bar-sm\"></div>",
                "profileUrl": "https://stackoverflow.com/users/33264/matthewmartin",
                "canSeeDeletedPosts": true,
                "ab": {"new_user_inbox_message": {"v": "QuestionClosedEmailSent", "g": 3}}
            },
            "realtime": {"newest": false, "active": false, "tagged": true, "staleDisconnectIntervalInHours": 0},
            "events": {"postType": {"question": 1}, "postEditionSection": {"title": 1, "body": 2, "tags": 3}},
            "story": {"minCompleteBodyLength": 75, "likedTagsMaxLength": 300, "dislikedTagsMaxLength": 300},
            "jobPreferences": {"maxNumDeveloperRoles": 2, "maxNumIndustries": 4},
            "svgIconPath": "https://cdn.sstatic.net/Img/svg-icons",
            "svgIconHash": "41ca7234d37d"
        }, {
            "userProfile": {"openGraphAPIKey": "4a307e43-b625-49bb-af15-ffadf2bda017"},
            "userMessaging": {"showNewFeatureNotice": true},
            "tags": {},
            "subscriptions": {"defaultMaxTrueUpSeats": 1000},
            "snippets": {"renderDomain": "stacksnippets.net", "snippetsEnabled": true},
            "slack": {"sidebarAdDismissCookie": "slack-sidebar-ad", "sidebarAdDismissCookieExpirationDays": 60.0},
            "site": {
                "allowImageUploads": true,
                "enableImgurHttps": true,
                "enableUserHovercards": true,
                "forceHttpsImages": true,
                "styleCode": true
            },
            "intercom": {"appId": "inf0secd", "hostBaseUrl": "https://stacksnippets.net"},
            "paths": {},
            "monitoring": {"clientTimingsAbsoluteTimeout": 30000, "clientTimingsDebounceTimeout": 1000},
            "mentions": {"maxNumUsersInDropdown": 50},
            "markdown": {"enableTables": true},
            "flags": {"allowRetractingCommentFlags": true, "allowRetractingFlags": true},
            "comments": {},
            "accounts": {"currentPasswordRequiredForChangingStackIdPassword": true}
        });
        StackExchange.using.setCacheBreakers({
            "js/adops.en.js": "22a9bd59b1e9",
            "js/ask.en.js": "e287ffdc77d4",
            "js/begin-edit-event.en.js": "cb9965ad8784",
            "js/events.en.js": "c6c8889b517b",
            "js/explore-qlist.en.js": "22610455f68f",
            "js/full-anon.en.js": "5161fccab23c",
            "js/full.en.js": "f81a3c6dcad5",
            "js/help.en.js": "b49b1b0c233e",
            "js/highlightjs-loader.en.js": "bb374a2289c0",
            "js/inline-tag-editing.en.js": "64af4cae422c",
            "js/keyboard-shortcuts.en.js": "3131cd802b4b",
            "js/markdown-it-loader.en.js": "ecbf27350e73",
            "js/mobile.en.js": "e8e35effc1e7",
            "js/moderator.en.js": "68a7976fb7ec",
            "js/postCollections-transpiled.en.js": "5e7b256b3872",
            "js/post-validation.en.js": "84327ab5c35a",
            "js/prettify-full.en.js": "705fa0e6be8d",
            "js/question-editor.en.js": "",
            "js/review.en.js": "64b30f5cf8ce",
            "js/review-v2-transpiled.en.js": "6665606b25b3",
            "js/revisions.en.js": "f20f2a79bffd",
            "js/stacks-editor.en.js": "9c3f30b07967",
            "js/tageditor.en.js": "4f30af0fdc59",
            "js/tageditornew.en.js": "37fd6b26bc64",
            "js/tagsuggestions.en.js": "bdfe20bf5338",
            "js/wmd.en.js": "4f962fbc00f6",
            "js/snippet-javascript-codemirror.en.js": "b66c70749b7e"
        });
        StackExchange.using("gps", function () {
            StackExchange.gps.init(true);
        });
    </script>
    <noscript id="noscript-css">
        <style>body, .top-bar {
            margin-top: 1.9em
        }</style>
    </noscript>
</head>
<body class="unified-theme theme-dark">
<div id="notify-container"></div>
<div id="custom-header"></div>

<header class="top-bar js-top-bar top-bar__network _fixed">
    <div class="wmx12 mx-auto grid ai-center h100" role="menubar">
        <div class="-main grid--cell">
            <a href="#" class="left-sidebar-toggle p0 ai-center jc-center js-left-sidebar-toggle" role="menuitem"
               aria-haspopup="true" aria-controls="left-sidebar" aria-expanded="false"><span class="ps-relative"></span></a>
            <div class="topbar-dialog leftnav-dialog js-leftnav-dialog dno">
                <div class="left-sidebar js-unpinned-left-sidebar" data-can-be="left-sidebar"
                     data-is-here-when="sm md lg"></div>
            </div>
            <a href="https://stackoverflow.com" class="-logo js-gps-track"
               data-gps-track="top_nav.click({is_current:false, location:0, destination:8})">
                <span class="-img _glyph">Stack Overflow</span>
            </a>


        </div>

        <ol class="list-reset grid gs4" role="presentation">


            <li class="grid--cell">
                <a href="#"
                   class="-marketing-link js-gps-track js-products-menu"
                   aria-controls="products-popover"
                   data-controller="s-popover"
                   data-action="s-popover#toggle"
                   data-s-popover-placement="bottom"
                   data-s-popover-toggle-class="is-selected"
                   data-gps-track="top_nav.products.click({location:0, destination:1})"
                   data-ga="[&quot;top navigation&quot;,&quot;products menu click&quot;,null,null,null]">
                    Products
                </a>
            </li>

        </ol>
        <div class="s-popover ws2 mtn2 p0"
             id="products-popover"
             role="menu"
             aria-hidden="true">
            <div class="s-popover--arrow"></div>
            <ol class="list-reset s-anchors s-anchors__inherit">
                <li class="m6">
                    <a href="/" class="bar-sm p6 d-block h:bg-black-100 js-gps-track"
                       data-gps-track="top_nav.products.click({location:0, destination:2})"
                       data-ga="[&quot;top navigation&quot;,&quot;public qa submenu click&quot;,null,null,null]">
                        <span class="fs-body1 d-block">Stack Overflow</span>
                        <span class="fs-caption d-block fc-light">Public questions &amp; answers</span>
                    </a>
                </li>
                <li class="m6">
                    <a href="/teams" class="bar-sm p6 d-block h:bg-black-100 js-gps-track"
                       data-gps-track="top_nav.products.click({location:0, destination:3})"
                       data-ga="[&quot;top navigation&quot;,&quot;teams submenu click&quot;,null,null,null]">
                        <span class="fs-body1 d-block">Stack Overflow for Teams</span>
                        <span class="fs-caption d-block fc-light">Where developers &amp; technologists share private knowledge with coworkers</span>
                    </a>
                </li>
                <li class="m6">
                    <a href="/jobs?so_source=ProductsMenu&so_medium=StackOverflow"
                       class="bar-sm p6 d-block h:bg-black-100 js-gps-track"
                       data-gps-track="top_nav.products.click({location:0, destination:9})"
                       data-ga="[&quot;top navigation&quot;,&quot;jobs submenu click&quot;,null,null,null]">
                        <span class="fs-body1 d-block">Jobs</span>
                        <span class="fs-caption d-block fc-light">Programming &amp; related technical career opportunities</span>
                    </a>
                </li>
                <li class="m6">
                    <a href="https://stackoverflow.com/talent" class="bar-sm p6 d-block h:bg-black-100 js-gps-track"
                       data-gps-track="top_nav.products.click({location:0, destination:5})"
                       data-ga="[&quot;top navigation&quot;,&quot;talent submenu click&quot;,null,null,null]">
                        <span class="fs-body1 d-block">Talent</span>
                        <span
                            class="fs-caption d-block fc-light">Recruit tech talent &amp; build your employer brand</span>
                    </a>
                </li>
                <li class="m6">
                    <a href="https://stackoverflow.com/advertising"
                       class="bar-sm p6 d-block h:bg-black-100 js-gps-track"
                       data-gps-track="top_nav.products.click({location:0, destination:6})"
                       data-ga="[&quot;top navigation&quot;,&quot;advertising submenu click&quot;,null,null,null]">
                        <span class="fs-body1 d-block">Advertising</span>
                        <span class="fs-caption d-block fc-light">Reach developers &amp; technologists worldwide</span>
                    </a>
                </li>
                <li class="bg-black-025 bt bc-black-075 py6 px6 bbr-sm">
                    <a href="/company" class="fc-light d-block py6 px6 h:fc-black-800 js-gps-track"
                       data-gps-track="top_nav.products.click({location:0, destination:7})"
                       data-ga="[&quot;top navigation&quot;,&quot;about submenu click&quot;,null,null,null]">About the
                        company</a>
                </li>
            </ol>
        </div>

        <form id="search" role="search" action=/search class="grid--cell fl-grow1 searchbar px12 js-searchbar "
              autocomplete="off">
            <div class="ps-relative">
                <input name="q"
                       type="text"
                       placeholder="Search&#x2026;"
                       value=""
                       autocomplete="off"
                       maxlength="240"
                       class="s-input s-input__search js-search-field "
                       aria-label="Search"
                       aria-controls="top-search"
                       data-controller="s-popover"
                       data-action="focus->s-popover#show"
                       data-s-popover-placement="bottom-start"/>
                <svg aria-hidden="true" class="s-input-icon s-input-icon__search svg-icon iconSearch" width="18"
                     height="18" viewBox="0 0 18 18">
                    <path
                        d="M18 16.5l-5.14-5.18h-.35a7 7 0 10-1.19 1.19v.35L16.5 18l1.5-1.5zM12 7A5 5 0 112 7a5 5 0 0110 0z"/>
                </svg>
                <div class="s-popover p0 wmx100 wmn4 sm:wmn-initial js-top-search-popover s-popover--arrow__tl"
                     id="top-search" role="menu">
                    <div class="js-spinner p24 grid ai-center jc-center d-none">
                        <div class="s-spinner s-spinner__sm fc-orange-400">
                            <div class="v-visible-sr">Loading&#x2026;</div>
                        </div>
                    </div>

                    <span class="v-visible-sr js-screen-reader-info"></span>
                    <div class="js-ac-results overflow-y-auto hmx3 d-none"></div>

                    <div class="js-search-hints" aria-describedby="Tips for searching"></div>
                </div>
            </div>
        </form>


        <ol class="overflow-x-auto ml-auto -secondary grid ai-center list-reset h100 user-logged-in"
            role="presentation">
            <li class="-item searchbar-trigger"><a href="#" class="-link js-searchbar-trigger" role="button"
                                                   aria-label="Search" aria-haspopup="true" aria-controls="search"
                                                   title="Click to show search">
                <svg aria-hidden="true" class="svg-icon iconSearch" width="18" height="18" viewBox="0 0 18 18">
                    <path
                        d="M18 16.5l-5.14-5.18h-.35a7 7 0 10-1.19 1.19v.35L16.5 18l1.5-1.5zM12 7A5 5 0 112 7a5 5 0 0110 0z"/>
                </svg>
            </a></li>
            <li class="-item">
                <a href="/users/33264/matthewmartin" class="my-profile js-gps-track"
                   data-gps-track="profile_summary.click()">
                    <div class="gravatar-wrapper-24" title="MatthewMartin"><img
                        src="https://www.gravatar.com/avatar/4ffb7620821b43c340d40187ca5820ff?s=48&amp;d=identicon&amp;r=PG"
                        alt="" width="24" height="24" class="bar-sm -avatar js-avatar-me"></div>
                    <span class="v-visible-sr">MatthewMartin</span>

                    <div class="-rep js-header-rep" title="your reputation: 29,858" aria-hidden="true">29,858</div>
                    <span class="v-visible-sr">, 29,858 reputation</span>
                    <div class="-badges">
                        <span title="30 gold badges" aria-hidden="true"><span class="badge1">&#9679;</span><span
                            class="badgecount">30</span></span><span class="v-visible-sr">30 gold badges</span><span
                        title="101 silver badges" aria-hidden="true"><span class="badge2">&#9679;</span><span
                        class="badgecount">101</span></span><span class="v-visible-sr">101 silver badges</span><span
                        title="159 bronze badges" aria-hidden="true"><span class="badge3">&#9679;</span><span
                        class="badgecount">159</span></span><span class="v-visible-sr">159 bronze badges</span></div>
                </a>
            </li>
            <li class="-item inbox-button-item">
                <a href="https://stackexchange.com/users/15651?tab=inbox" class="-link js-inbox-button"
                   aria-label="Inbox" title="Recent inbox messages" role="menuitem" aria-haspopup="true"
                   aria-expanded="false" data-unread-count="0">
                    <svg aria-hidden="true" class="svg-icon iconInbox" width="20" height="18" viewBox="0 0 20 18">
                        <path
                            d="M4.63 1h10.56a2 2 0 011.94 1.35L20 10.79V15a2 2 0 01-2 2H2a2 2 0 01-2-2v-4.21l2.78-8.44c.25-.8 1-1.36 1.85-1.35zm8.28 12l2-2h2.95l-2.44-7.32a1 1 0 00-.95-.68H5.35a1 1 0 00-.95.68L1.96 11h2.95l2 2h6z"/>
                    </svg>
                    <span class="indicator-badge js-unread-count _important d-none">0</span>
                </a>
            </li>
            <li class="-item achievements-button-item">
                <a href="https://stackexchange.com/users/15651?tab=reputation" class="-link js-achievements-button"
                   data-unread-class="_highlighted-positive"
                   aria-label="Achievements (10 new reputation)" title="You have new reputation changes" role="menuitem"
                   aria-haspopup="true" aria-expanded="false" data-unread-count="10" data-lit-up="false">
                    <svg aria-hidden="true" class="svg-icon iconAchievements" width="18" height="18"
                         viewBox="0 0 18 18">
                        <path
                            d="M15 2V1H3v1H0v4c0 1.6 1.4 3 3 3v1c.4 1.5 3 2.6 5 3v2H5s-1 1.5-1 2h10c0-.4-1-2-1-2h-3v-2c2-.4 4.6-1.5 5-3V9c1.6-.2 3-1.4 3-3V2h-3zM3 7c-.5 0-1-.5-1-1V4h1v3zm8.4 2.5L9 8 6.6 9.4l1-2.7L5 5h3l1-2.7L10 5h2.8l-2.3 1.8 1 2.7h-.1zM16 6c0 .5-.5 1-1 1V4h1v2z"/>
                    </svg>
                    <span class="indicator-badge js-unread-count _positive">+10</span>
                </a>
            </li>
            <li class="-item review-button-item">
                <a href="/review" class="-link js-gps-track js-review-button _danger-indicator"
                   aria-label="Review (needs attention)"
                   title="Review queues - help improve the site"
                   role="menuitem" aria-haspopup="true" aria-expanded="false"
                   data-gps-track="review_popup.click({ in_danger: true })">
                    <svg aria-hidden="true" class="svg-icon iconReviewQueue" width="18" height="18" viewBox="0 0 18 18">
                        <path
                            d="M11 12.47l5-4.97V3a2 2 0 00-2-2H2a2 2 0 00-2 2v12a2 2 0 002 2h6.5l-2.79-2.8a1 1 0 010-1.4l2.1-2.1a1 1 0 011.4 0L11 12.47zM2 7h10v2H2V7zm0-4h12v2H2V3zm0 10v-2h3v2H2zm9 4.5l7-7L16.5 9 11 14.5 8.5 12 7 13.5l4 4z"/>
                    </svg>
                </a>
            </li>
            <li class="-item help-button-item">
                <a href="#" class="-link js-help-button" title="Help Center and other resources" role="menuitem"
                   aria-haspopup="true" aria-controls="topbar-help-dialog"
                   data-ga="[&quot;top navigation&quot;,&quot;help menu click&quot;,null,null,null]">
                    <svg aria-hidden="true" class="svg-icon iconHelp" width="18" height="18" viewBox="0 0 18 18">
                        <path
                            d="M9 1a8 8 0 100 16A8 8 0 009 1zm.81 12.13c-.02.71-.55 1.15-1.24 1.13-.66-.02-1.17-.49-1.15-1.2.02-.72.56-1.18 1.22-1.16.7.03 1.2.51 1.17 1.23zM11.77 8c-.3.34-.65.65-1.02.91l-.53.37c-.26.2-.42.43-.5.69a4 4 0 00-.09.75c0 .05-.03.16-.18.16H7.88c-.16 0-.18-.1-.18-.15.03-.66.12-1.21.4-1.66.4-.49.88-.9 1.43-1.22.16-.12.28-.25.38-.39a1.34 1.34 0 00.02-1.71c-.24-.31-.51-.46-1.03-.46-.51 0-.8.26-1.02.6-.21.33-.18.73-.18 1.1H5.75c0-1.38.35-2.25 1.1-2.76.52-.35 1.17-.5 1.93-.5 1 0 1.79.18 2.49.71.64.5.98 1.18.98 2.12 0 .57-.2 1.05-.48 1.44z"/>
                    </svg>
                </a>
            </li>
            <div class="topbar-dialog help-dialog js-help-dialog dno" id="topbar-help-dialog" role="menu">
                <div class="modal-content">
                    <ul>
                        <li>
                            <a href="/tour" class="js-gps-track" data-gps-track="help_popup.click({ item_type:1 })"
                               data-ga="[&quot;top navigation&quot;,&quot;tour submenu click&quot;,null,null,null]">
                                Tour
                                <span class="item-summary">
                                    Start here for a quick overview of the site
                                </span>
                            </a>
                        </li>
                        <li>
                            <a href="/help" class="js-gps-track"
                               data-gps-track="help_popup.click({ item_type:4 })"
                               data-ga="[&quot;top navigation&quot;,&quot;help center&quot;,null,null,null]">
                                Help Center
                                <span class="item-summary">
                                Detailed answers to any questions you might have
                            </span>
                            </a>
                        </li>
                        <li>
                            <a href="https://meta.stackoverflow.com" class="js-gps-track"
                               data-gps-track="help_popup.click({ item_type:2 })"
                               data-ga="[&quot;top navigation&quot;,&quot;meta submenu click&quot;,null,null,null]">
                                Meta
                                <span class="item-summary">
                                            Discuss the workings and policies of this site
                                        </span>
                            </a>
                        </li>
                        <li>
                            <a href="https://stackoverflow.com/company" class="js-gps-track"
                               data-gps-track="help_popup.click({ item_type:6 })"
                               data-ga="[&quot;top navigation&quot;,&quot;about us submenu click&quot;,null,null,null]">
                                About Us
                                <span class="item-summary">
                                        Learn more about Stack Overflow the company
                                    </span>
                            </a>
                        </li>
                        <li>
                            <a href="https://stackoverflowbusiness.com/?ref=topbar_help" class="js-gps-track"
                               data-gps-track="help_popup.click({ item_type:7 })"
                               data-ga="[&quot;top navigation&quot;,&quot;business submenu click&quot;,null,null,null]">
                                Business
                                <span class="item-summary">
                                        Learn more about hiring developers or posting ads with us
                                    </span>
                            </a>
                        </li>
                    </ul>
                </div>
            </div>
            <li class="-item site-switcher-item">
                <a href="https://stackexchange.com" class="-link js-site-switcher-button js-gps-track"
                   data-gps-track="site_switcher.show"
                   aria-label="Site switcher"
                   title="A list of all 176 Stack Exchange sites"
                   role="menuitem" aria-haspopup="true" aria-expanded="false"
                   data-ga="[&quot;top navigation&quot;,&quot;stack exchange click&quot;,null,null,null]">
                    <svg aria-hidden="true" class="svg-icon iconStackExchange" width="18" height="18"
                         viewBox="0 0 18 18">
                        <path
                            d="M15 1H3a2 2 0 00-2 2v2h16V3a2 2 0 00-2-2zM1 13c0 1.1.9 2 2 2h8v3l3-3h1a2 2 0 002-2v-2H1v2zm16-7H1v4h16V6z"/>
                    </svg>
                </a>
            </li>


            <li class="js-topbar-dialog-corral" role="presentation">


                <div class="topbar-dialog siteSwitcher-dialog dno" role="menu">
                    <div class="header">
                        <h3>
                            <a href="https://stackoverflow.com">current community</a>
                        </h3>
                    </div>
                    <div class="modal-content bg-powder-050">
                        <ul class="current-site">
                            <li class="grid">
                                <div class="fl1">
                                    <a href="https://stackoverflow.com"
                                       class="current-site-link site-link js-gps-track grid gs8 gsx"
                                       data-id="1"
                                       data-gps-track="site_switcher.click({ item_type:3 })">
                                        <div class="favicon favicon-stackoverflow site-icon grid--cell"
                                             title="Stack Overflow"></div>
                                        <span class="grid--cell fl1">
            Stack Overflow
        </span>
                                    </a>

                                </div>
                                <div class="related-links">
                                    <a href="https://stackoverflow.com/help" class="js-gps-track"
                                       data-gps-track="site_switcher.click({ item_type:14 })">help</a>
                                    <a href="https://chat.stackoverflow.com/?tab=site&amp;host=stackoverflow.com"
                                       class="js-gps-track"
                                       data-gps-track="site_switcher.click({ item_type:6 })">chat</a>
                                    <a href="https://stackoverflow.com/users/logout" class="js-gps-track"
                                       data-gps-track="site_switcher.click({ item_type:8 })">log out</a>
                                </div>

                            </li>
                            <li class="related-site grid">
                                <div class="L-shaped-icon-container">
                                    <span class="L-shaped-icon"></span>
                                </div>

                                <a href="https://meta.stackoverflow.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="552"
                                   data-gps-track="site.switch({ target_site:552, item_type:3 }),site_switcher.click({ item_type:4 })">
                                    <div class="favicon favicon-stackoverflowmeta site-icon grid--cell"
                                         title="Meta Stack Overflow"></div>
                                    <span class="grid--cell fl1">
            Meta Stack Overflow
        </span>
                                </a>

                            </li>
                        </ul>
                    </div>

                    <div class="header" id="your-communities-header">
                        <h3>
                            <a href="https://stackexchange.com/users/15651/?tab=accounts">your communities</a>
                        </h3>

                        <a href="#" id="edit-pinned-sites">edit</a>
                        <a href="#" id="cancel-pinned-sites" style="display: none;">cancel</a>
                    </div>
                    <div class="modal-content" id="your-communities-section">

                        <ul class="my-sites">
                            <li>
                                <a href="https://stackoverflow.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="1"
                                   data-gps-track="site.switch({ target_site:1, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-stackoverflow site-icon grid--cell"
                                         title="Stack Overflow"></div>
                                    <span class="grid--cell fl1">
            Stack Overflow
        </span>
                                    <span class="rep-score grid--cell">29,858</span>
                                </a>

                            </li>
                            <li>
                                <a href="https://buddhism.stackexchange.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="565"
                                   data-gps-track="site.switch({ target_site:565, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-buddhism site-icon grid--cell" title="Buddhism"></div>
                                    <span class="grid--cell fl1">
            Buddhism
        </span>
                                    <span class="rep-score grid--cell">7,006</span>
                                </a>

                            </li>
                            <li>
                                <a href="https://esperanto.stackexchange.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="662"
                                   data-gps-track="site.switch({ target_site:662, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-esperanto site-icon grid--cell"
                                         title="Esperanto Language"></div>
                                    <span class="grid--cell fl1">
            Esperanto Language
        </span>
                                    <span class="rep-score grid--cell">131</span>
                                </a>

                            </li>
                            <li>
                                <a href="https://vegetarianism.stackexchange.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="670"
                                   data-gps-track="site.switch({ target_site:670, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-vegetarianism site-icon grid--cell"
                                         title="Veganism &amp; Vegetarianism"></div>
                                    <span class="grid--cell fl1">
            Veganism &amp; Vegetarianism
        </span>
                                    <span class="rep-score grid--cell">882</span>
                                </a>

                            </li>
                            <li>
                                <a href="https://pm.stackexchange.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="208"
                                   data-gps-track="site.switch({ target_site:208, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-pm site-icon grid--cell"
                                         title="Project Management"></div>
                                    <span class="grid--cell fl1">
            Project Management
        </span>
                                    <span class="rep-score grid--cell">140</span>
                                </a>

                            </li>
                            <li>
                                <a href="https://softwareengineering.stackexchange.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="131"
                                   data-gps-track="site.switch({ target_site:131, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-softwareengineering site-icon grid--cell"
                                         title="Software Engineering"></div>
                                    <span class="grid--cell fl1">
            Software Engineering
        </span>
                                    <span class="rep-score grid--cell">881</span>
                                </a>

                            </li>
                            <li>
                                <a href="https://dba.stackexchange.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="182"
                                   data-gps-track="site.switch({ target_site:182, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-dba site-icon grid--cell"
                                         title="Database Administrators"></div>
                                    <span class="grid--cell fl1">
            Database Administrators
        </span>
                                    <span class="rep-score grid--cell">372</span>
                                </a>

                            </li>
                            <li>
                                <a href="https://english.stackexchange.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="97"
                                   data-gps-track="site.switch({ target_site:97, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-english site-icon grid--cell"
                                         title="English Language &amp; Usage"></div>
                                    <span class="grid--cell fl1">
            English Language &amp; Usage
        </span>
                                    <span class="rep-score grid--cell">2,409</span>
                                </a>

                            </li>
                            <li>
                                <a href="https://linguistics.stackexchange.com"
                                   class=" site-link js-gps-track grid gs8 gsx"
                                   data-id="312"
                                   data-gps-track="site.switch({ target_site:312, item_type:3 }),site_switcher.click({ item_type:1 })">
                                    <div class="favicon favicon-linguistics site-icon grid--cell"
                                         title="Linguistics"></div>
                                    <span class="grid--cell fl1">
            Linguistics
        </span>
                                    <span class="rep-score grid--cell">2,814</span>
                                </a>

                            </li>
                        </ul>
                        <div class="pinned-site-editor-container" style="display: none;">
                            <input type="hidden" name="fkey"
                                   value="e65640ce4fbe13142433c9ec7e081225b004e8a26f3543fa5b88e765fa6767bd">
                            <div class="grid p12">
                                <div class="grid--cell fl1 ps-relative">
                                    <input id="js-site-search-txt"
                                           type="text"
                                           class="s-input s-input__sm w100 h100 site-filter-input"
                                           value=""
                                           placeholder="Add a Stack Exchange community"/>
                                    <ul class="js-found-sites found-sites hmx1 l0 r0 ps-absolute overflow-y-auto"></ul>
                                </div>
                                <button class="ml8 s-btn s-btn__sm" type="submit" id="pin-site-btn" disabled="disabled">
                                    Add
                                </button>
                            </div>
                            <ul class="pinned-site-list sortable" data-custom-list="True">
                            </ul>
                            <div class="grid p12 jc-end">
                                <a class="grid--cell s-btn s-btn__sm js-reset-pinned-sites" href="#">Reset</a>
                                <button class="ml8 grid--cell s-btn s-btn__primary s-btn__sm" type="submit"
                                        id="save-pinned-sites-btn" disabled="disabled">Save
                                </button>
                            </div>
                        </div>
                    </div>

                    <div class="header">
                        <h3><a href="https://stackexchange.com/sites">more stack exchange communities</a>
                        </h3>
                        <a href="https://stackoverflow.blog" class="fr">company blog</a>
                    </div>
                    <div class="modal-content">
                        <div class="child-content"></div>
                    </div>
                </div>

            </li>
        </ol>
    </div>
</header>

<script>
    StackExchange.ready(function () {
        StackExchange.topbar.init();
    });
    StackExchange.scrollPadding.setPaddingTop(50, 10);    </script>


<div class="container">


    <div id="left-sidebar" data-is-here-when="" class="left-sidebar js-pinned-left-sidebar ps-relative">
        <div class="left-sidebar--sticky-container js-sticky-leftnav">
            <nav role="navigation">
                <ol class="nav-links">
                    <li class="">
                        <a
                            href="/"
                            class="pl8 js-gps-track nav-links--link"

                            data-gps-track="top_nav.click({is_current:false, location:0, destination:8})">
                            <div class="grid ai-center">
                                <div class="grid--cell truncate">
                                    Home
                                </div>
                            </div>
                        </a>
                    </li>
                    <li>
                        <ol class="nav-links">
                            <li class="fs-fine tt-uppercase ml8 mt16 mb4 fc-light">Public</li>

                            <li class="">
                                <a id="nav-questions"
                                   href="/questions"
                                   class="pl8 js-gps-track nav-links--link -link__with-icon"

                                   data-gps-track="top_nav.click({is_current:false, location:0, destination:1})">
                                    <svg aria-hidden="true" class="svg-icon iconGlobe" width="18" height="18"
                                         viewBox="0 0 18 18">
                                        <path
                                            d="M9 1a8 8 0 100 16A8 8 0 009 1zM8 15.32a6.4 6.4 0 01-5.23-7.75L7 11.68v.8c0 .88.12 1.32 1 1.32v1.52zm5.72-2c-.2-.66-1-1.32-1.72-1.32h-1v-2c0-.44-.56-1-1-1H6V7h1c.44 0 1-.56 1-1V5h2c.88 0 1.4-.72 1.4-1.6v-.33a6.4 6.4 0 012.32 10.24v.01z"/>
                                    </svg>
                                    <span class="-link--channel-name">Stack Overflow</span>
                                </a>
                            </li>


                            <li class="">
                                <a id="nav-tags"
                                   href="/tags"
                                   class=" js-gps-track nav-links--link"

                                   data-gps-track="top_nav.click({is_current:false, location:0, destination:2})">
                                    <div class="grid ai-center">
                                        <div class="grid--cell truncate">
                                            Tags
                                        </div>
                                    </div>
                                </a>
                            </li>
                            <li class="">
                                <a id="nav-users"
                                   href="/users"
                                   class=" js-gps-track nav-links--link"

                                   data-gps-track="top_nav.click({is_current:false, location:0, destination:3})">
                                    <div class="grid ai-center">
                                        <div class="grid--cell truncate">
                                            Users
                                        </div>
                                    </div>
                                </a>
                            </li>
                            <li class="fs-fine tt-uppercase ml8 mt16 mb4 fc-light">Find a Job</li>
                            <li class="">
                                <a id="nav-jobs"
                                   href="/jobs?so_medium=StackOverflow&amp;so_source=SiteNav"
                                   class=" js-gps-track nav-links--link"

                                   data-gps-track="top_nav.click({is_current:false, location:0, destination:6})">
                                    <div class="grid ai-center">
                                        <div class="grid--cell truncate">
                                            Jobs
                                        </div>
                                    </div>
                                </a>
                            </li>
                            <li class="">
                                <a id="nav-companies"
                                   href="/jobs/companies?so_medium=StackOverflow&amp;so_source=SiteNav"
                                   class=" js-gps-track nav-links--link"

                                   data-gps-track="top_nav.click({is_current:false, location:0, destination:12})">
                                    <div class="grid ai-center">
                                        <div class="grid--cell truncate">
                                            Companies
                                        </div>
                                    </div>
                                </a>
                            </li>
                        </ol>
                    </li>
                    <li>
                        <ol class="nav-links">
                            <li class="grid ai-center jc-space-between ml8 mt24 mb4">
                                <div class="grid--cell tt-uppercase fs-fine fc-light">Teams</div>
                                <div class="grid--cell fs-fine fc-light mr4">
                                    <a href="javascript:void(0)" class="s-link s-link__inherit js-gps-track"
                                       role="button"
                                       aria-controls="popover-teams-create-cta"
                                       data-controller="s-popover"
                                       data-action="s-popover#toggle"
                                       data-s-popover-placement="bottom-start"
                                       data-s-popover-toggle-class="is-selected"
                                       data-gps-track="teams.create.left-sidenav.click({ Action: ShowInfo })"
                                       data-ga="[&quot;teams left navigation&quot;,&quot;left nav show teams info&quot;,null,null,null]">
                                        What&#x2019;s this?
                                    </a>

                                </div>
                            </li>
                            <li class="ps-relative">
                                <a href="https://stackoverflow.com/teams"
                                   class="pl8 js-gps-track nav-links--link"
                                   title="Stack Overflow for Teams is a private, secure spot for your organization's questions and answers."
                                   data-gps-track="teams.create.left-sidenav.click({ Action: TeamsClick })"
                                   data-ga="[&quot;teams left navigation&quot;,&quot;left nav team click&quot;,&quot;stackoverflow.com/teams&quot;,null,null]">
                                    <div class="grid ai-center">
                                        <div class="grid--cell s-avatar va-middle bg-orange-400">
                                            <div class="s-avatar--letter mtn1">
                                                <svg aria-hidden="true" class="svg-icon iconBriefcaseSm" width="14"
                                                     height="14" viewBox="0 0 14 14">
                                                    <path
                                                        d="M4 3a1 1 0 011-1h4a1 1 0 011 1v1h.5c.83 0 1.5.67 1.5 1.5v5c0 .83-.67 1.5-1.5 1.5h-7A1.5 1.5 0 012 10.5v-5C2 4.67 2.67 4 3.5 4H4V3zm5 1V3H5v1h4z"/>
                                                </svg>
                                            </div>
                                            <svg aria-hidden="true"
                                                 class="native s-avatar--badge svg-icon iconShieldXSm" width="9"
                                                 height="10" viewBox="0 0 9 10">
                                                <path
                                                    d="M0 1.84L4.5 0 9 1.84v3.17C9 7.53 6.3 10 4.5 10 2.7 10 0 7.53 0 5.01V1.84z"
                                                    fill="var(--white)"/>
                                                <path
                                                    d="M1 2.5L4.5 1 8 2.5v2.51C8 7.34 5.34 9 4.5 9 3.65 9 1 7.34 1 5.01V2.5zm2.98 3.02L3.2 7h2.6l-.78-1.48a.4.4 0 01.15-.38c.34-.24.73-.7.73-1.14 0-.71-.5-1.23-1.41-1.23-.92 0-1.39.52-1.39 1.23 0 .44.4.9.73 1.14.12.08.18.23.15.38z"
                                                    fill="var(--black-500)"/>
                                            </svg>
                                        </div>
                                        <div class="grid--cell pl6">
                                            Free 30 Day Trial
                                        </div>
                                    </div>
                                </a>
                            </li>
                        </ol>
                    </li>
                </ol>
            </nav>
        </div>


        <div class="s-popover w-auto p16"
             id="popover-teams-create-cta"
             role="menu"
             aria-hidden="true">
            <div class="s-popover--arrow"></div>

            <div class="ps-relative overflow-hidden">
                <p class="mb2"><strong>Teams</strong></p>
                <p class="mb16 fs-caption fc-medium">Q&amp;A for Work</p>
                <p class="mb8 fs-caption fc-medium">

                    Stack Overflow for Teams is a private, secure spot for you and
                    your coworkers to find and share information.
                </p>
                <a href="https://stackoverflow.com/teams"
                   class="js-gps-track ws-nowrap d-block"
                   data-gps-track="teams.create.left-sidenav.click({ Action: CtaClick })"
                   data-ga="[&quot;teams left navigation&quot;,&quot;left nav cta&quot;,&quot;stackoverflow.com/teams&quot;,null,null]">
                    Learn more </a>
            </div>

            <div class="ps-absolute t8 r8">
                <svg width="53" height="49" fill="none" xmlns="http://www.w3.org/2000/svg">
                    <path d="M49 11l.2 31H18.9L9 49v-7H4V8h31" fill="#CCEAFF"/>
                    <path d="M44.5 19v-.3l-.2-.1-18-13-.1-.1H.5v33h4V46l.8-.6 9.9-6.9h29.3V19z" stroke="#1060E1"
                          stroke-miterlimit="10"/>
                    <path d="M31 2l6-1.5 7 2V38H14.9L5 45v-7H1V6h25l5-4z" fill="#fff"/>
                    <path d="M7 16.5h13m-13 6h14m-14 6h18" stroke="#1060E1" stroke-miterlimit="10"/>
                    <path d="M39 30a14 14 0 1 0 0-28 14 14 0 0 0 0 28z" fill="#FFB935"/>
                    <path d="M50.5 14a13.5 13.5 0 1 1-27 0 13.5 13.5 0 0 1 27 0z" stroke="#F48024"
                          stroke-miterlimit="10"/>
                    <path
                        d="M32.5 21.5v-8h9v8h-9zm2-9.5V9.3A2.5 2.5 0 0 1 37 6.8a2.5 2.5 0 0 1 2.5 2.5V12h-5zm2 3v2m1-2v2"
                        stroke="#fff" stroke-miterlimit="10"/>
                </svg>
            </div>
        </div>

    </div>


    <div id="content" class="snippet-hidden">


        <div
            class="grid w90 wmx10 mx-auto my64 sm:mt0 sm:mb32 ai-center jc-center lg:fd-column lg:ta-center sm:ta-left">
            <div class="grid--cell mr48 lg:mr0 lg:mb24 sm:d-none">
                <img class="md:w100" width="438"
                     src="https://cdn.sstatic.net/Img/conduct/conduct-illo.svg?v=98156033ebec">
            </div>
            <div class="grid--cell wmx5 w100">
                <h1 class="fs-display2 p-ff-roboto-slab fc-orange-500 mb16 mln2">Code of Conduct</h1>
                <p class="fs-headline1 p-ff-roboto-slab fc-medium">This Code of Conduct helps us build a community that
                    is rooted in kindness, collaboration, and mutual respect.</p>
                <p class="fs-body3 fc-medium">
                    Whether you&#x2019;ve come to ask questions or to generously share what you know, join us in
                    building a community where all people feel welcome and can participate, regardless of expertise or
                    identity.
                </p>
                <p class="fs-body3 fc-medium">We commit to enforcing and improving the Code of Conduct. It applies to
                    everyone using Stack Overflow and the Stack Exchange network, including our team, <a
                        href="/help/site-moderators">moderators</a>, and anyone posting to Q&amp;A sites or chat rooms.
                </p>
            </div>
        </div>

        <div class="wmx9 mx-auto bg-powder-050 p64 mb64 sm:pt24 sm:pb24 sm:pr24 sm:pl24 bar-lg">
            <h2 id="expectations" class="fs-headline1 p-ff-roboto-slab mb48 sm:mb24">Our Expectations</h2>

            <div class="grid grid__allcells6 gs64 gsx fs-body2 lh-md fc-medium md:fd-column">
                <div class="grid--cell">
                    <p class="mb48 sm:mb24">
                <span class="fw-bold d-block mb4">
                    If you&#x2019;re here to get help, make it as easy as possible for others to help you.
                </span>
                        <a href="/help/how-to-ask">Follow our guidelines</a> and remember that our community is made
                        possible by volunteers.
                    </p>
                    <p class="mb0 md:mb48 sm:mb24">
                <span class="fw-bold d-block mb4">
                    If you&#x2019;re here to help others, be patient and welcoming.
                </span>
                        Learning how to participate in our community can be hard. Offer support if you see someone
                        struggling or otherwise in need of help.
                    </p>
                </div>
                <div class="grid--cell">
                    <p class="mb48 sm:mb24">
                <span class="fw-bold d-block mb4">
                    Be clear and constructive when giving feedback, and be open when receiving it.
                </span>
                        Edits, comments, and suggestions are healthy parts of our community.
                    </p>
                    <p class="mb0">
                <span class="fw-bold d-block mb4">
                    Be inclusive and respectful.
                </span>
                        Avoid sarcasm and be careful with jokes &#x2014; tone is hard to decipher online. Prefer
                        gender-neutral language when uncertain. If a situation makes it hard to be friendly, stop
                        participating and move on.
                    </p>
                </div>
            </div>
        </div>

        <div class="wmx9 mx-auto px64 mb64 fs-body2 lh-md fc-medium sm:pr24 sm:pl24">
            <h2 id="unacceptable-behavior" class="fs-headline1 p-ff-roboto-slab mb48">Unacceptable Behavior</h2>
            <div id="unfriendly-language" class="grid grid__allcells6 gs64 gsx md:fd-column">
                <div class="grid--cell">
                    <p class="mb48 sm:mb24">
                <span class="fw-bold d-block mb4">
                    No subtle put-downs or unfriendly language.
                </span>
                        Even if you don&#x2019;t intend it, this can have a negative impact on others.
                    </p>
                </div>
            </div>
            <div class="grid grid__allcells6 gs64 gsx mb16 fw-bold md:d-none">
                <div class="grid--cell">
                    Unfriendly
                </div>
                <div class="grid--cell">
                    Friendly
                </div>
            </div>
            <div class="grid grid__allcells6 gs64 gsx mb24 md:fd-column bar-md bg-powder-050 py24">
                <div class="grid--cell">
                    <div class="grid md:mb12">
                        <div class="grid--cell mr6">
                            <svg aria-hidden="true" class="fc-red-500 svg-icon iconClear" width="18" height="18"
                                 viewBox="0 0 18 18">
                                <path
                                    d="M15 4.41L13.59 3 9 7.59 4.41 3 3 4.41 7.59 9 3 13.59 4.41 15 9 10.41 13.59 15 15 13.59 10.41 9 15 4.41z"/>
                            </svg>
                        </div>
                        <div class="grid--cell">
                            &#x201C;You could Google this in 5 seconds.&#x201D;
                        </div>
                    </div>
                </div>
                <div class="grid--cell">
                    <div class="grid">
                        <div class="grid--cell mr6">
                            <svg aria-hidden="true" class="fc-green-400 svg-icon iconCheckmark" width="18" height="18"
                                 viewBox="0 0 18 18">
                                <path d="M16 4.41L14.59 3 6 11.59 2.41 8 1 9.41l5 5 10-10z"/>
                            </svg>
                        </div>
                        <div class="grid--cell">
                            &#x201C;This is called Invariance and Covariance. If you Google it, you&#x2019;ll find
                            tutorials that can explain it much better than we can in an answer here.&#x201D;
                        </div>
                    </div>
                </div>
            </div>
            <div class="grid grid__allcells6 gs64 gsx mb24 md:fd-column">
                <div class="grid--cell">
                    <div class="grid md:mb12">
                        <div class="grid--cell mr6">
                            <svg aria-hidden="true" class="fc-red-500 svg-icon iconClear" width="18" height="18"
                                 viewBox="0 0 18 18">
                                <path
                                    d="M15 4.41L13.59 3 9 7.59 4.41 3 3 4.41 7.59 9 3 13.59 4.41 15 9 10.41 13.59 15 15 13.59 10.41 9 15 4.41z"/>
                            </svg>
                        </div>
                        <div class="grid--cell">
                            &#x201C;If you bothered to read my question, you&#x2019;d know it&#x2019;s not a duplicate.&#x201D;
                        </div>
                    </div>
                </div>
                <div class="grid--cell">
                    <div class="grid">
                        <div class="grid--cell mr6">
                            <svg aria-hidden="true" class="fc-green-400 svg-icon iconCheckmark" width="18" height="18"
                                 viewBox="0 0 18 18">
                                <path d="M16 4.41L14.59 3 6 11.59 2.41 8 1 9.41l5 5 10-10z"/>
                            </svg>
                        </div>
                        <div class="grid--cell">
                            &#x201C;I don&#x2019;t think this is a duplicate. My question is about cement board, while
                            the question you linked is about drywall.&#x201D;
                        </div>
                    </div>
                </div>
            </div>
            <div class="grid grid__allcells6 gs64 gsx mb24 md:fd-column bar-md bg-powder-050 py24">
                <div class="grid--cell">
                    <div class="grid md:mb12">
                        <div class="grid--cell mr6">
                            <svg aria-hidden="true" class="fc-red-500 svg-icon iconClear" width="18" height="18"
                                 viewBox="0 0 18 18">
                                <path
                                    d="M15 4.41L13.59 3 9 7.59 4.41 3 3 4.41 7.59 9 3 13.59 4.41 15 9 10.41 13.59 15 15 13.59 10.41 9 15 4.41z"/>
                            </svg>
                        </div>
                        <div class="grid--cell">
                            &#x201C;Are you speaking English? If so, I can&#x2019;t tell.&#x201D;
                        </div>
                    </div>
                </div>
                <div class="grid--cell">
                    <div class="grid">
                        <div class="grid--cell mr6">
                            <svg aria-hidden="true" class="fc-green-400 svg-icon iconCheckmark" width="18" height="18"
                                 viewBox="0 0 18 18">
                                <path d="M16 4.41L14.59 3 6 11.59 2.41 8 1 9.41l5 5 10-10z"/>
                            </svg>
                        </div>
                        <div class="grid--cell">
                            &#x201C;I&#x2019;m having trouble understanding your question. I think you&#x2019;re asking
                            how to add a swap after system installation. Is that correct?&#x201D;
                        </div>
                    </div>
                </div>
            </div>
            <div class="grid grid__allcells6 gs64 gsx mb48 md:fd-column">
                <div class="grid--cell">
                    <div class="grid mb16 md:mb12">
                        <div class="grid--cell mr6">
                            <svg aria-hidden="true" class="fc-red-500 svg-icon iconClear" width="18" height="18"
                                 viewBox="0 0 18 18">
                                <path
                                    d="M15 4.41L13.59 3 9 7.59 4.41 3 3 4.41 7.59 9 3 13.59 4.41 15 9 10.41 13.59 15 15 13.59 10.41 9 15 4.41z"/>
                            </svg>
                        </div>
                        <div class="grid--cell">
                            &#x201C;I came to get help, not to get my question edited.&#x201D;
                        </div>
                    </div>
                </div>
                <div class="grid--cell">
                    <div class="grid">
                        <div class="grid--cell mr6">
                            <svg aria-hidden="true" class="fc-green-400 svg-icon iconCheckmark" width="18" height="18"
                                 viewBox="0 0 18 18">
                                <path d="M16 4.41L14.59 3 6 11.59 2.41 8 1 9.41l5 5 10-10z"/>
                            </svg>
                        </div>
                        <div class="grid--cell">
                            &#x201C;Thanks for trying to help, but your edit isn&#x2019;t what I meant. I&#x2019;ve
                            removed your edit, and have updated my question so it&#x2019;s clearer.&#x201D;
                        </div>
                    </div>
                </div>
            </div>
            <div id="personal-attacks" class="grid grid__allcells6 gs64 gsx md:fd-column">
                <div class="grid--cell">
                    <p class="mb48">
                <span class="fw-bold d-block mb4">
                    No name-calling or personal attacks.
                </span>
                        Focus on the content, not the person. This includes terms that feel personal even when they&#x27;re
                        applied to content (e.g. &#x201C;lazy&#x201D;).
                    </p>
                </div>
            </div>
            <div class="grid grid__allcells6 gs64 gsx md:fd-column">
                <div class="grid--cell">
                    <p class="mb48">
                <span class="fw-bold d-block mb4">
                    No bigotry.
                </span>
                        We don&#x2019;t tolerate any language likely to offend or alienate people based on race, gender,
                        sexual orientation, or religion &#x2014; and those are just a few examples. Use stated pronouns
                        (when known). When in doubt, don&#x27;t use language that might offend or alienate.
                    </p>
                </div>
            </div>
            <div class="grid grid__allcells6 gs64 gsx md:fd-column">
                <div class="grid--cell">
                    <p class="mb0">
                <span class="fw-bold d-block mb4">
                    No harassment.
                </span>
                        This includes, but isn&#x2019;t limited to: bullying, intimidation, vulgar language, direct or
                        indirect threats, sexually suggestive remarks, patterns of inappropriate social contact, and
                        sustained disruptions of discussion.
                    </p>
                </div>
            </div>
        </div>

        <div
            class="wmx9 mx-auto bg-powder-050 p64 mb64 bar-lg fs-body2 lh-md fc-medium sm:pt24 sm:pb24 sm:pr24 sm:pl24">
            <h2 id="reporting" class="fs-headline1 p-ff-roboto-slab mb48 md:mb24">Reporting</h2>

            <p class="wmx5 mb48 sm:mb24">Every person contributes to building a kind, respectful community. If you find
                unacceptable behavior directed at yourself or others, you can:</p>
            <div class="grid grid__allcells6 gs64 gsx sm:mb0 sm:fd-column">
                <div class="grid--cell md:mb24">
                    <p>
                <span class="fw-bold d-block mb4">
                    Flag the harmful content.
                </span>
                        Depending on the content, flagging will alert moderators or trigger an automatic deletion.
                    </p>
                    <a class="s-btn s-btn__primary" href="/help/flagging">Learn more</a>
                </div>
                <div class="grid--cell md:mb0">
                    <p>
                <span class="fw-bold d-block mb4">
                    Contact us.
                </span>
                        We&#x2019;ll respond as quickly as we can.
                    </p>
                    <a class="s-btn s-btn__primary" href="/contact">Contact us</a>
                </div>
            </div>
        </div>

        <div class="wmx9 mx-auto px64 mb64 fs-body2 lh-md fc-medium sm:pr24 sm:pl24">
            <h2 id="enforcement" class="fs-headline1 p-ff-roboto-slab mb48">Enforcement</h2>

            <p class="mb48 wmx5">We take your reports seriously. Those who don’t follow the Code of Conduct <span
                class="fw-bold fs-italic">in good faith</span> may face repercussions deemed appropriate by our
                moderation team. This is how moderators generally handle misconduct:</p>

            <div class="grid grid__allcells4 gs64 gsx md:fd-column">
                <div class="grid--cell">
                    <div class="grid grid__center bg-yellow-200 bar-circle p-ff-roboto-slab mb16 fs-title"
                         style="width: 40px; height: 40px;">
                        1
                    </div>
                    <p class="mb48">
                <span class="fw-bold d-block mb4">
                    Warning
                </span>
                        For most first-time misconduct, moderators will remove offending content and send a warning.
                        Most issues are resolved here.
                    </p>
                </div>
                <div class="grid--cell">
                    <div class="grid grid__center bg-orange-200 bar-circle p-ff-roboto-slab mb16 fs-title"
                         style="width:40px; height: 40px;">
                        2
                    </div>
                    <p class="mb48">
                <span class="fw-bold d-block mb4">
                    Account Suspension
                </span>
                        For repetitive misconduct or behavior containing harassment, bigotry, or abuse, moderators will
                        impose a temporary suspension (one day or more, depending on the violation).
                    </p>
                </div>
                <div class="grid--cell">
                    <div class="grid grid__center bg-red-200 bar-circle p-ff-roboto-slab mb16 fs-title"
                         style="width:40px; height: 40px;">
                        3
                    </div>
                    <p class="mb48">
                <span class="fw-bold d-block mb4">
                    Account Expulsion
                </span>
                        For very rare cases, moderators will expel people who display a pattern of harmful destructive
                        behavior toward our community.
                    </p>
                </div>
            </div>

            <p class="mb0 wmx5">All actions will be taken on a case-by-case basis at the discretion of our moderators.
                If you have concerns about how a moderator has handled a situation, <a href="/contact">contact us</a>
                directly.</p>
        </div>

        <div
            class="wmx9 mx-auto bg-powder-050 p64 mb32 bar-lg fs-body2 lh-md fc-medium sm:pt24 sm:pb24 sm:pr24 sm:pl24">
            <div class="grid grid__allcells6 gs64 gsx md:fd-column">
                <div class="grid--cell md:mb16">
                    <p class="mb16">We created this Code of Conduct because it reinforces the respect that we, as a
                        community, expect from one another. Having a code also provides us with clear avenues to correct
                        our culture should it stray off-course.</p>
                    <p class="mb0">We welcome your feedback on this and every other aspect of what we do at Stack
                        Overflow and the Stack Exchange network. Thank you for working with us to build a kind,
                        collaborative, and respectful community.</p>
                </div>
                <p class="grid--cell fc-powder-600 mb0 fs-italic">
                    This text incorporates ideas and language from the <a
                    href="https://coralproject.net/code-of-conduct/">Coral Project</a> and <a
                    href="https://open.buffer.com/code-of-conduct/">Buffer</a> codes of conduct.
                </p>
            </div>
        </div>
        <div class="wmx9 mx-auto pb12 fs-body2 lh-md fc-medium fs-caption sm:pr24 sm:pl24">
            Last update: 2019-10-10
        </div>
    </div>
</div>
<footer id="footer" class="site-footer js-footer" role="contentinfo">
    <div class="site-footer--container">
        <div class="site-footer--logo">

            <a href="https://stackoverflow.com">
                <svg aria-hidden="true" class="native svg-icon iconLogoGlyphMd" width="32" height="37"
                     viewBox="0 0 32 37">
                    <path d="M26 33v-9h4v13H0V24h4v9h22z" fill="#BCBBBB"/>
                    <path
                        d="M21.5 0l-2.7 2 9.9 13.3 2.7-2L21.5 0zM26 18.4L13.3 7.8l2.1-2.5 12.7 10.6-2.1 2.5zM9.1 15.2l15 7 1.4-3-15-7-1.4 3zm14 10.79l.68-2.95-16.1-3.35L7 23l16.1 2.99zM23 30H7v-3h16v3z"
                        fill="#F48024"/>
                </svg>
            </a>
        </div>
        <nav class="site-footer--nav">
            <div class="site-footer--col site-footer--col__visible js-footer-col" data-name="default">
                <h5 class="-title"><a href="https://stackoverflow.com" class="js-gps-track"
                                      data-gps-track="footer.click({ location: 0, link: 15})">Stack Overflow</a></h5>
                <ul class="-list js-primary-footer-links">
                    <li class="-item"><a href="/questions" class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 16})">Questions</a></li>
                    <li class="-item"><a href="https://stackoverflow.com/jobs" class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 17})">Jobs</a></li>
                    <li class="-item"><a href="https://stackoverflow.com/jobs/directory/developer-jobs"
                                         class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 11})">Developer Jobs
                        Directory</a></li>
                    <li class="-item"><a href="https://stackoverflow.com/jobs/salary" class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 28})">Salary Calculator</a>
                    </li>
                    <li class="-item"><a href="/help" class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 3 })">Help</a></li>
                    <li class="-item"><a onclick='StackExchange.switchMobile("on")' class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 12 })">Mobile</a></li>
                </ul>
            </div>
            <div class="site-footer--col site-footer--col__visible js-footer-col" data-name="default">
                <h5 class="-title"><a href="https://stackoverflowbusiness.com" class="js-gps-track"
                                      data-gps-track="footer.click({ location: 0, link: 19 })">Products</a></h5>
                <ul class="-list">
                    <li class="-item"><a href="https://stackoverflow.com/teams" class="js-gps-track -link"
                                         data-ga="[&quot;teams traffic&quot;,&quot;footer - site nav&quot;,&quot;stackoverflow.com/teams&quot;,null,{&quot;dimension4&quot;:&quot;teams&quot;}]"
                                         data-gps-track="footer.click({ location: 0, link: 29 })">Teams</a></li>
                    <li class="-item"><a href="https://stackoverflow.com/talent" class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 20 })">Talent</a></li>
                    <li class="-item"><a href="https://stackoverflow.com/advertising" class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 21 })">Advertising</a></li>
                    <li class="-item"><a href="https://stackoverflow.com/enterprise" class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 22 })">Enterprise</a></li>
                </ul>
            </div>
            <div class="site-footer--col site-footer--col__visible js-footer-col" data-name="default">
                <h5 class="-title"><a class="js-gps-track" data-gps-track="footer.click({ location: 0, link: 1 })"
                                      href="https://stackoverflow.com/company">Company</a></h5>
                <ul class="-list">
                    <li class="-item"><a class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 1 })"
                                         href="https://stackoverflow.com/company">About</a></li>
                    <li class="-item"><a class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 27 })"
                                         href="https://stackoverflow.com/company/press">Press</a></li>
                    <li class="-item"><a class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 9 })"
                                         href="https://stackoverflow.com/company/work-here">Work Here</a></li>
                    <li class="-item"><a class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 7 })"
                                         href="https://stackoverflow.com/legal">Legal</a></li>
                    <li class="-item"><a class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 8 })"
                                         href="https://stackoverflow.com/legal/privacy-policy">Privacy Policy</a></li>
                    <li class="-item"><a class="js-gps-track -link"
                                         data-gps-track="footer.click({ location: 0, link: 13 })"
                                         href="https://stackoverflow.com/company/contact">Contact Us</a></li>
                </ul>
            </div>
            <div class="site-footer--col site-footer--categories-nav site-footer--col__visible">
                <a href="#" class="site-footer--back js-footer-back">
                    <svg aria-hidden="true" class="svg-icon iconArrowLeftAlt" width="18" height="18"
                         viewBox="0 0 18 18">
                        <path d="M10.58 16L12 14.59 6.4 9 12 3.41 10.57 2l-7 7 7 7z"/>
                    </svg>
                </a>
                <div>
                    <h5 class="-title"><a href="https://stackexchange.com"
                                          data-gps-track="footer.click({ location: 0, link: 30 })">Stack Exchange<br>
                        Network</a></h5>
                    <ul class="-list">
                        <li class="-item"><a href="#" class="-link _expandable js-footer-category-trigger js-gps-track"
                                             data-gps-track="footer.click({ location: 0, link: 24 })"
                                             data-target="Technology">Technology</a></li>
                        <li class="-item"><a href="#" class="-link _expandable js-footer-category-trigger js-gps-track"
                                             data-gps-track="footer.click({ location: 0, link: 24 })"
                                             data-target="Life / Arts">Life / Arts</a></li>
                        <li class="-item"><a href="#" class="-link _expandable js-footer-category-trigger js-gps-track"
                                             data-gps-track="footer.click({ location: 0, link: 24 })"
                                             data-target="Culture / Recreation">Culture / Recreation</a></li>
                        <li class="-item"><a href="#" class="-link _expandable js-footer-category-trigger js-gps-track"
                                             data-gps-track="footer.click({ location: 0, link: 24 })"
                                             data-target="Science">Science</a></li>
                        <li class="-item"><a href="#" class="-link _expandable js-footer-category-trigger js-gps-track"
                                             data-gps-track="footer.click({ location: 0, link: 24 })"
                                             data-target="Other">Other</a></li>
                    </ul>
                </div>
            </div>
            <div class="site-footer--categories">
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Technology">
                    <ul class="-list">
                        <li class="-item"><a href="https://stackoverflow.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="professional and enthusiast programmers">Stack Overflow</a></li>
                        <li class="-item"><a href="https://serverfault.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="system and network administrators">Server Fault</a></li>
                        <li class="-item"><a href="https://superuser.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="computer enthusiasts and power users">Super User</a></li>
                        <li class="-item"><a href="https://webapps.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="power users of web applications">Web Applications</a></li>
                        <li class="-item"><a href="https://askubuntu.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="Ubuntu users and developers">Ask Ubuntu</a></li>
                        <li class="-item"><a href="https://webmasters.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="pro webmasters">Webmasters</a></li>
                        <li class="-item"><a href="https://gamedev.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="professional and independent game developers">Game Development</a>
                        </li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Technology">
                    <ul class="-list">
                        <li class="-item"><a href="https://tex.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="users of TeX, LaTeX, ConTeXt, and related typesetting systems">TeX -
                            LaTeX</a></li>
                        <li class="-item"><a href="https://softwareengineering.stackexchange.com"
                                             class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="professionals, academics, and students working within the systems development life cycle">Software
                            Engineering</a></li>
                        <li class="-item"><a href="https://unix.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="users of Linux, FreeBSD and other Un*x-like operating systems">Unix
                            &amp; Linux</a></li>
                        <li class="-item"><a href="https://apple.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="power users of Apple hardware and software">Ask Different
                            (Apple)</a></li>
                        <li class="-item"><a href="https://wordpress.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="WordPress developers and administrators">WordPress Development</a>
                        </li>
                        <li class="-item"><a href="https://gis.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="cartographers, geographers and GIS professionals">Geographic
                            Information Systems</a></li>
                        <li class="-item"><a href="https://electronics.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="electronics and electrical engineering professionals, students, and enthusiasts">Electrical
                            Engineering</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Technology">
                    <ul class="-list">
                        <li class="-item"><a href="https://android.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="enthusiasts and power users of the Android operating system">Android
                            Enthusiasts</a></li>
                        <li class="-item"><a href="https://security.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="information security professionals">Information Security</a></li>
                        <li class="-item"><a href="https://dba.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="database professionals who wish to improve their database skills and learn from others in the community">Database
                            Administrators</a></li>
                        <li class="-item"><a href="https://drupal.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="Drupal developers and administrators">Drupal Answers</a></li>
                        <li class="-item"><a href="https://sharepoint.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="SharePoint enthusiasts">SharePoint</a></li>
                        <li class="-item"><a href="https://ux.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="user experience researchers and experts">User Experience</a></li>
                        <li class="-item"><a href="https://mathematica.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="users of Wolfram Mathematica">Mathematica</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Technology">
                    <ul class="-list">
                        <li class="-item"><a href="https://salesforce.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="Salesforce administrators, implementation experts, developers and anybody in-between">Salesforce</a>
                        </li>
                        <li class="-item"><a href="https://expressionengine.stackexchange.com"
                                             class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="administrators, end users, developers and designers for ExpressionEngine&#xAE; CMS">ExpressionEngine&#xAE;
                            Answers</a></li>
                        <li class="-item"><a href="https://pt.stackoverflow.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="programadores profissionais e entusiastas">Stack Overflow em Portugu&#xEA;s</a>
                        </li>
                        <li class="-item"><a href="https://blender.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="people who use Blender to create 3D graphics, animations, or games">Blender</a>
                        </li>
                        <li class="-item"><a href="https://networkengineering.stackexchange.com"
                                             class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="network engineers">Network Engineering</a></li>
                        <li class="-item"><a href="https://crypto.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="software developers, mathematicians and others interested in cryptography">Cryptography</a>
                        </li>
                        <li class="-item"><a href="https://codereview.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="peer programmer code reviews">Code Review</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Technology">
                    <ul class="-list">
                        <li class="-item"><a href="https://magento.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="users of the Magento e-Commerce platform">Magento</a></li>
                        <li class="-item"><a href="https://softwarerecs.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="people seeking specific software recommendations">Software
                            Recommendations</a></li>
                        <li class="-item"><a href="https://dsp.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="practitioners of the art and science of signal, image and video processing">Signal
                            Processing</a></li>
                        <li class="-item"><a href="https://emacs.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="those using, extending or developing Emacs">Emacs</a></li>
                        <li class="-item"><a href="https://raspberrypi.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="users and developers of hardware and software for Raspberry Pi">Raspberry
                            Pi</a></li>
                        <li class="-item"><a href="https://ru.stackoverflow.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="&#x43F;&#x440;&#x43E;&#x433;&#x440;&#x430;&#x43C;&#x43C;&#x438;&#x441;&#x442;&#x43E;&#x432;">Stack
                            Overflow &#x43D;&#x430; &#x440;&#x443;&#x441;&#x441;&#x43A;&#x43E;&#x43C;</a></li>
                        <li class="-item"><a href="https://codegolf.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="programming puzzle enthusiasts and code golfers">Code Golf</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Technology">
                    <ul class="-list">
                        <li class="-item"><a href="https://es.stackoverflow.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="programadores y profesionales de la inform&#xE1;tica">Stack Overflow
                            en espa&#xF1;ol</a></li>
                        <li class="-item"><a href="https://ethereum.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="users of Ethereum, the decentralized application platform and smart contract enabled blockchain">Ethereum</a>
                        </li>
                        <li class="-item"><a href="https://datascience.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="Data science professionals, Machine Learning specialists, and those interested in learning more about the field">Data
                            Science</a></li>
                        <li class="-item"><a href="https://arduino.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="developers of open-source hardware and software that is compatible with Arduino">Arduino</a>
                        </li>
                        <li class="-item"><a href="https://bitcoin.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="Bitcoin crypto-currency enthusiasts">Bitcoin</a></li>
                        <li class="-item"><a href="https://sqa.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="software quality control experts, automation engineers, and software testers">Software
                            Quality Assurance &amp; Testing</a></li>
                        <li class="-item"><a href="https://sound.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="sound engineers, producers, editors, and enthusiasts">Sound
                            Design</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Technology">
                    <ul class="-list">
                        <li class="-item"><a href="https://windowsphone.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="enthusiasts and power users of Windows Phone OS">Windows Phone</a>
                        </li>
                        <li class="-item">
                            <a href="https://stackexchange.com/sites#technology" class="-link js-gps-track"
                               data-gps-track="footer.click({ location: 2, link: 26 })">
                                <strong>
                                    more (28)
                                </strong>
                            </a>
                        </li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Life / Arts">
                    <ul class="-list">
                        <li class="-item"><a href="https://photo.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="professional, enthusiast and amateur photographers">Photography</a>
                        </li>
                        <li class="-item"><a href="https://scifi.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="science fiction and fantasy enthusiasts">Science Fiction &amp;
                            Fantasy</a></li>
                        <li class="-item"><a href="https://graphicdesign.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="Graphic Design professionals, students, and enthusiasts">Graphic
                            Design</a></li>
                        <li class="-item"><a href="https://movies.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="movie and TV enthusiasts">Movies &amp; TV</a></li>
                        <li class="-item"><a href="https://music.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="musicians, students, and enthusiasts">Music: Practice &amp;
                            Theory</a></li>
                        <li class="-item"><a href="https://worldbuilding.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="writers/artists using science, geography and culture to construct imaginary worlds and settings">Worldbuilding</a>
                        </li>
                        <li class="-item"><a href="https://video.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="engineers, producers, editors, and enthusiasts spanning the fields of video, and media creation">Video
                            Production</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Life / Arts">
                    <ul class="-list">
                        <li class="-item"><a href="https://cooking.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="professional and amateur chefs">Seasoned Advice (cooking)</a></li>
                        <li class="-item"><a href="https://diy.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="contractors and serious DIYers">Home Improvement</a></li>
                        <li class="-item"><a href="https://money.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="people who want to be financially literate">Personal Finance &amp;
                            Money</a></li>
                        <li class="-item"><a href="https://academia.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="academics and those enrolled in higher education">Academia</a></li>
                        <li class="-item"><a href="https://law.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="legal professionals, students, and others with experience or interest in law">Law</a>
                        </li>
                        <li class="-item"><a href="https://fitness.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="physical fitness professionals, athletes, trainers, and those providing health-related needs">Physical
                            Fitness</a></li>
                        <li class="-item"><a href="https://gardening.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="gardeners and landscapers">Gardening &amp; Landscaping</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Life / Arts">
                    <ul class="-list">
                        <li class="-item"><a href="https://parenting.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="parents, grandparents, nannies and others with a parenting role">Parenting</a>
                        </li>
                        <li class="-item">
                            <a href="https://stackexchange.com/sites#lifearts" class="-link js-gps-track"
                               data-gps-track="footer.click({ location: 2, link: 26 })">
                                <strong>
                                    more (10)
                                </strong>
                            </a>
                        </li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Culture / Recreation">
                    <ul class="-list">
                        <li class="-item"><a href="https://english.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="linguists, etymologists, and serious English language enthusiasts">English
                            Language &amp; Usage</a></li>
                        <li class="-item"><a href="https://skeptics.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="scientific skepticism">Skeptics</a></li>
                        <li class="-item"><a href="https://judaism.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="those who base their lives on Jewish law and tradition and anyone interested in learning more">Mi
                            Yodeya (Judaism)</a></li>
                        <li class="-item"><a href="https://travel.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="road warriors and seasoned travelers">Travel</a></li>
                        <li class="-item"><a href="https://christianity.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="committed Christians, experts in Christianity and those interested in learning more">Christianity</a>
                        </li>
                        <li class="-item"><a href="https://ell.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="speakers of other languages learning English">English Language
                            Learners</a></li>
                        <li class="-item"><a href="https://japanese.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="students, teachers, and linguists wanting to discuss the finer points of the Japanese language">Japanese
                            Language</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Culture / Recreation">
                    <ul class="-list">
                        <li class="-item"><a href="https://chinese.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="students, teachers, and linguists wanting to discuss the finer points of the Chinese language">Chinese
                            Language</a></li>
                        <li class="-item"><a href="https://french.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="students, teachers, and linguists wanting to discuss the finer points of the French language">French
                            Language</a></li>
                        <li class="-item"><a href="https://german.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="speakers of German wanting to discuss the finer points of the language and translation">German
                            Language</a></li>
                        <li class="-item"><a href="https://hermeneutics.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="professors, theologians, and those interested in exegetical analysis of biblical texts">Biblical
                            Hermeneutics</a></li>
                        <li class="-item"><a href="https://history.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="historians and history buffs">History</a></li>
                        <li class="-item"><a href="https://spanish.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="linguists, teachers, students and Spanish language enthusiasts in general wanting to discuss the finer points of the language">Spanish
                            Language</a></li>
                        <li class="-item"><a href="https://islam.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="Muslims, experts in Islam, and those interested in learning more about Islam">Islam</a>
                        </li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Culture / Recreation">
                    <ul class="-list">
                        <li class="-item"><a href="https://rus.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="&#x43B;&#x438;&#x43D;&#x433;&#x432;&#x438;&#x441;&#x442;&#x43E;&#x432; &#x438; &#x44D;&#x43D;&#x442;&#x443;&#x437;&#x438;&#x430;&#x441;&#x442;&#x43E;&#x432; &#x440;&#x443;&#x441;&#x441;&#x43A;&#x43E;&#x433;&#x43E; &#x44F;&#x437;&#x44B;&#x43A;&#x430;">&#x420;&#x443;&#x441;&#x441;&#x43A;&#x438;&#x439;
                            &#x44F;&#x437;&#x44B;&#x43A;</a></li>
                        <li class="-item"><a href="https://russian.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="students, teachers, and linguists wanting to discuss the finer points of the Russian language">Russian
                            Language</a></li>
                        <li class="-item"><a href="https://gaming.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="passionate videogamers on all platforms">Arqade (gaming)</a></li>
                        <li class="-item"><a href="https://bicycles.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="people who build and repair bicycles, people who train cycling, or commute on bicycles">Bicycles</a>
                        </li>
                        <li class="-item"><a href="https://rpg.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="gamemasters and players of tabletop, paper-and-pencil role-playing games">Role-playing
                            Games</a></li>
                        <li class="-item"><a href="https://anime.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="anime and manga fans">Anime &amp; Manga</a></li>
                        <li class="-item"><a href="https://puzzling.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="those who create, solve, and study puzzles">Puzzling</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Culture / Recreation">
                    <ul class="-list">
                        <li class="-item"><a href="https://mechanics.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="mechanics and DIY enthusiast owners of cars, trucks, and motorcycles">Motor
                            Vehicle Maintenance &amp; Repair</a></li>
                        <li class="-item"><a href="https://boardgames.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="people who like playing board games, designing board games or modifying the rules of existing board games">Board
                            &amp; Card Games</a></li>
                        <li class="-item"><a href="https://bricks.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="LEGO&#xAE; and building block enthusiasts">Bricks</a></li>
                        <li class="-item"><a href="https://homebrew.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="dedicated home brewers and serious enthusiasts">Homebrewing</a></li>
                        <li class="-item"><a href="https://martialarts.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="students and teachers of all martial arts">Martial Arts</a></li>
                        <li class="-item"><a href="https://outdoors.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="people who love being outdoors enjoying nature and wilderness, and learning about the required skills and equipment">The
                            Great Outdoors</a></li>
                        <li class="-item"><a href="https://poker.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="serious players and enthusiasts of poker">Poker</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Culture / Recreation">
                    <ul class="-list">
                        <li class="-item"><a href="https://chess.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="serious players and enthusiasts of chess">Chess</a></li>
                        <li class="-item"><a href="https://sports.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="participants in team and individual sport activities">Sports</a>
                        </li>
                        <li class="-item">
                            <a href="https://stackexchange.com/sites#culturerecreation" class="-link js-gps-track"
                               data-gps-track="footer.click({ location: 2, link: 26 })">
                                <strong>
                                    more (16)
                                </strong>
                            </a>
                        </li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Science">
                    <ul class="-list">
                        <li class="-item"><a href="https://mathoverflow.net" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="professional mathematicians">MathOverflow</a></li>
                        <li class="-item"><a href="https://math.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="people studying math at any level and professionals in related fields">Mathematics</a>
                        </li>
                        <li class="-item"><a href="https://stats.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="people interested in statistics, machine learning, data analysis, data mining, and data visualization">Cross
                            Validated (stats)</a></li>
                        <li class="-item"><a href="https://cstheory.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="theoretical computer scientists and researchers in related fields">Theoretical
                            Computer Science</a></li>
                        <li class="-item"><a href="https://physics.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="active researchers, academics and students of physics">Physics</a>
                        </li>
                        <li class="-item"><a href="https://chemistry.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="scientists, academics, teachers, and students in the field of chemistry">Chemistry</a>
                        </li>
                        <li class="-item"><a href="https://biology.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="biology researchers, academics, and students">Biology</a></li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Science">
                    <ul class="-list">
                        <li class="-item"><a href="https://cs.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="students, researchers and practitioners of computer science">Computer
                            Science</a></li>
                        <li class="-item"><a href="https://philosophy.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="those interested in the study of the fundamental nature of knowledge, reality, and existence">Philosophy</a>
                        </li>
                        <li class="-item"><a href="https://linguistics.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="professional linguists and others with an interest in linguistic research and theory">Linguistics</a>
                        </li>
                        <li class="-item"><a href="https://psychology.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="practitioners, researchers, and students in cognitive science, psychology, neuroscience, and psychiatry">Psychology
                            &amp; Neuroscience</a></li>
                        <li class="-item"><a href="https://scicomp.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="scientists using computers to solve scientific problems">Computational
                            Science</a></li>
                        <li class="-item">
                            <a href="https://stackexchange.com/sites#science" class="-link js-gps-track"
                               data-gps-track="footer.click({ location: 2, link: 26 })">
                                <strong>
                                    more (10)
                                </strong>
                            </a>
                        </li>
                    </ul>
                </div>
                <div class="site-footer--col site-footer--category js-footer-col" data-name="Other">
                    <ul class="-list">
                        <li class="-item"><a href="https://meta.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="meta-discussion of the Stack Exchange family of Q&amp;A websites">Meta
                            Stack Exchange</a></li>
                        <li class="-item"><a href="https://stackapps.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="apps, scripts, and development with the Stack Exchange API">Stack
                            Apps</a></li>
                        <li class="-item"><a href="https://api.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="programmatic interaction with Stack Exchange sites">API</a></li>
                        <li class="-item"><a href="https://data.stackexchange.com" class="-link js-gps-track"
                                             data-gps-track="footer.click({ location: 2, link: 25 })"
                                             title="querying Stack Exchange data using SQL">Data</a></li>
                    </ul>
                </div>

            </div>
        </nav>
        <div class="site-footer--copyright fs-fine">
            <ul class="-list">
                <li class="-item"><a class="js-gps-track -link" data-gps-track="footer.click({ location: 0, link:4 })"
                                     href="https://stackoverflow.blog?blb=1">Blog</a></li>
                <li class="-item"><a href="https://www.facebook.com/officialstackoverflow/" class="-link js-gps-track"
                                     data-gps-track="footer.click({ location: 0, link: 31 })">Facebook</a></li>
                <li class="-item"><a href="https://twitter.com/stackoverflow" class="-link js-gps-track"
                                     data-gps-track="footer.click({ location: 0, link: 32 })">Twitter</a></li>
                <li class="-item"><a href="https://linkedin.com/company/stack-overflow" class="-link js-gps-track"
                                     data-gps-track="footer.click({ location: 0, link: 33 })">LinkedIn</a></li>
                <li class="-item"><a href="https://www.instagram.com/thestackoverflow" class="-link js-gps-track"
                                     data-gps-track="footer.click({ location: 0, link: 36 })">Instagram</a></li>
            </ul>

            <p class="mt-auto mb24">
                site design / logo &#169; 2020 Stack Exchange Inc; user contributions licensed under <a
                href="https://stackoverflow.com/help/licensing">cc by-sa</a>. <span id="svnrev">rev&nbsp;2020.12.18.38240</span>
            </p>
        </div>
    </div>

</footer>

<script>StackExchange.ready(function () {
    StackExchange.responsiveness.addSwitcher();
})</script>
<noscript>
    <div id="noscript-warning">Stack Overflow works best with JavaScript enabled
    </div>
</noscript>

<script>
    (function (i, s, o, g, r, a, m) {
        i['GoogleAnalyticsObject'] = r;
        i[r] = i[r] || function () {
            (i[r].q = i[r].q || []).push(arguments)
        }, i[r].l = 1 * new Date();
        a = s.createElement(o),
            m = s.getElementsByTagName(o)[0];
        a.async = 1;
        a.src = g;
        m.parentNode.insertBefore(a, m);
    })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

    StackExchange.ready(function () {

        StackExchange.ga.init({
            sendTitles: true,
            tracker: window.ga,
            trackingCodes: [
                'UA-108242619-1'
            ],
            checkDimension: 'dimension42'
        });

        StackExchange.ga.setDimension('dimension1', '15651');

        StackExchange.ga.setDimension('dimension10', 'NotLooking');


        StackExchange.ga.setDimension('dimension3', 'Help/Conduct');


        StackExchange.ga.trackPageView();
    });
    /**/

    var _qevents = _qevents || [],
        _comscore = _comscore || [];
    (function () {
        var s = document.getElementsByTagName('script')[0],
            qc = document.createElement('script');
        qc.async = true;
        qc.src = 'https://secure.quantserve.com/quant.js';
        s.parentNode.insertBefore(qc, s);
        _qevents.push({qacct: "p-c1rF4kxgLUzNc"});/**/
        var sc = document.createElement('script');
        sc.async = true;
        sc.src = 'https://sb.scorecardresearch.com/beacon.js';
        s.parentNode.insertBefore(sc, s);
        _comscore.push({c1: "2", c2: "17440561"});
    })();
</script>


</body>
</html>
