"""
Author: Daniel G
Author Link: https://stackoverflow.com/users/207432/daniel-g
License: CC BY-SA 2.5
Date: 1270328265
Answer Url: https://stackoverflow.com/questions/2572582/return-a-list-of-imported-python-modules-used-in-a-script/2572654#2572654
"""

__title__ = "Return a list of imported Python modules used in a script?"
__version__ = "0.1.5"
__author__ = "Daniel G"
__license__ = "CC BY-SA 2.5"
__copyright__ = "Copyright 1270328265 by Daniel G"
